#
#	SatSAT.rb - Ruby version of SatSAT
#
#	SatSAT, a set of programs developed by JA1BML, produces satellite 
#	forcast form individual data disclosed on the JAMSAT web page. 
#
#	SatSAT.rb is a script written in Ruby, and performs all the 
#	functions provided by the original SatSAT, i.e., file dowonloading 
#   from the web, text re-formatting and sorting.
#   
#	ver.0.1 JE0AWL    4 Apr. 2009
#   ver.0.2 JE0AWL    1 May  2009
#   ver.0.3 JE0AWL   10 Nov. 2009
#

require 'open-uri'

base_url = "http://www.jamsat.or.jp/pred/"  
loc = "tokyo/"
satlist = {
	"VO" => "hamsat.txt",   # VO-52
	"FO" => "fo-29.txt",    # FO-29
	"A5" => "ao-51.txt",    # AO-51
	"A2" => "ao-27.txt",    # AO-27
	"S5" => "so-50.txt",    # SO-50
	"S6" => "so-67.txt"     # SO-67
}
base_dir = "C:\\MyDocuments\\Web\\sat\\"
filelist = {
#	"SatSATrb_LIN"  => "(VO|FO)$",
#	"SatSATrb_FM"   => "(A5|A2|S5|S6)$",
#	"SatSATrb_MIX"  => "..$",
	"SatSATrb"      => "(VO|FO)$"
};
ext = ".html"
#ext = ".txt"

mmm2mm = {
	"Jan" => "01", "Feb" => "02", "Mar" => "03", "Apr" => "04", 
	"May" => "05", "Jun" => "06", "Jul" => "07", "Aug" => "08", 
	"Sep" => "09", "Oct" => "10", "Nov" => "11", "Dec" => "12"
}

data = Array.new
satlist.each {|sat, satfile|
	
	finp = open((base_url + loc + satfile), "r")
	p "open " + satfile
	data_buf = Array.new
	finp.each {|line|
		
		if line =~ /^(Sun|Mon|Tue|Wed|Thu|Fri|Sat)\s+(\d\d)(\w\w\w)(\d\d)\s+(.+)\s+\w\w\w\s+\d+/
			data_buf[0] = ($4 + mmm2mm[$3] + $2 + $1)
			buf = $5
		elsif line =~ /^\s+(.+)\s+\w\w\w\s+\d+/
			buf = $1
		else
			next
		end
	
		if buf =~ /(\d\d):(\d\d):\d\d\s+\d\d:(\d\d):\d\d\s+\d\d:(\d\d):\d\d\s+\d\d:(\d\d):\d\d\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\.\d.*/
			data_buf[1] = sprintf("%s%s-%s-%s(%2d) %X%X%X %2d", $1, $2, $3, $4, $5.to_i, ($6.to_i+15)/30%12, ($7.to_i+15)/30%12, ($8.to_i+15)/30%12, $9.to_i)
			data_buf[2] = sat
			data.push(data_buf.join(" "))
		end
	
	}
	
	finp.close
}


filelist.each {|filename, sats|
	fout = open(base_dir + filename + ext, "w")
	fout.puts("<html><head><title>"+filename+"</title></head><body><pre>") if ext==".html"

	date = Time.now.strftime("%y%m%d")
	fout.puts(Time.now.strftime("%d%a"))

	re = Regexp.new(sats)
	
	data.sort.each {|line|
		if line =~ re
			if line[0..5]<date
				next
			elsif line[0..5]>date
				date = line[0..5]
				fout.puts(line[4..8])
			end
			
			fout.puts(line[4..(line.length-1)].sub(/Sun|Mon|Tue|Wed|Thu|Fri|Sat/, ""))
		end
	}

	fout.puts("</pre></html></body>") if ext==".html"
	fout.close
}
